import * as t from 'io-ts';
import { FactoryEventNames, InstallerEventNames } from '../../../constants';
import { ExtractSchemaTypes } from '../../../schemas';
export declare const CreateDeploymentSchema: {
    Namespace: string;
    Description: string;
    Path: string;
    Method: "POST";
    Mode: "ASYNC";
    Params: t.TypeC<{}>;
    Body: t.IntersectionC<[t.TypeC<{
        applicationName: t.StringC;
        version: t.StringC;
        eventStoreId: t.StringC;
    }>, t.PartialC<{
        domain: t.StringC;
    }>]>;
    Query: t.TypeC<{}>;
    Event: t.TypeC<{
        name: t.LiteralC<InstallerEventNames.createDeployment>;
        payload: t.IntersectionC<[t.TypeC<{
            userId: t.StringC;
            applicationName: t.StringC;
            version: t.StringC;
            eventStoreId: t.StringC;
        }>, t.PartialC<{
            domain: t.StringC;
            deploymentTag: t.StringC;
        }>]>;
    }>;
    Result: t.IntersectionC<[t.TypeC<{
        deploymentId: t.StringC;
        applicationName: t.StringC;
        version: t.StringC;
        domains: t.ArrayC<t.StringC>;
    }>, t.PartialC<{
        eventStoreId: t.StringC;
    }>]>;
    ArgumentsTransformer: (args: {} & {
        applicationName: string;
        version: string;
        eventStoreId: string;
    } & {
        domain?: string | undefined;
    } & {}) => {
        params: {};
        body: {} & {
            applicationName: string;
            version: string;
            eventStoreId: string;
        } & {
            domain?: string | undefined;
        } & {};
        query: {};
    };
};
export declare type CreateDeployment = ExtractSchemaTypes<typeof CreateDeploymentSchema>;
export declare const DropDeploymentSchema: {
    Namespace: string;
    Description: string;
    Path: string;
    Method: "DELETE";
    Mode: "ASYNC";
    Params: t.TypeC<{
        deploymentId: t.StringC;
    }>;
    Body: t.PartialC<{
        withEventStore: t.BooleanC;
    }>;
    Query: t.TypeC<{}>;
    Event: t.TypeC<{
        name: t.LiteralC<InstallerEventNames.dropDeployment>;
        payload: t.IntersectionC<[t.TypeC<{
            userId: t.StringC;
            deploymentId: t.StringC;
        }>, t.PartialC<{
            withEventStore: t.BooleanC;
        }>]>;
    }>;
    Result: t.VoidC;
    ArgumentsTransformer: ({ deploymentId, withEventStore }: {
        deploymentId: string;
    } & {
        withEventStore?: boolean | undefined;
    } & {}) => {
        params: {
            deploymentId: string;
        };
        body: {
            withEventStore: boolean | undefined;
        };
        query: {};
    };
};
export declare type DropDeployment = ExtractSchemaTypes<typeof DropDeploymentSchema>;
export declare const ListDeploymentsSchema: {
    Namespace: string;
    Description: string;
    Path: string;
    Method: "GET";
    Mode: "SYNC";
    Params: t.TypeC<{}>;
    Body: t.TypeC<{}>;
    Query: t.PartialC<{
        applicationName: t.StringC;
    }>;
    Event: t.TypeC<{
        name: t.LiteralC<InstallerEventNames.listDeployments>;
        payload: t.IntersectionC<[t.TypeC<{
            userId: t.StringC;
        }>, t.PartialC<{
            applicationName: t.StringC;
        }>]>;
    }>;
    Result: t.ArrayC<t.IntersectionC<[t.TypeC<{
        deploymentId: t.StringC;
        applicationName: t.StringC;
        version: t.StringC;
        domains: t.ArrayC<t.StringC>;
    }>, t.PartialC<{
        eventStoreId: t.StringC;
    }>]>>;
    ArgumentsTransformer: ({ applicationName }?: {} & {} & {
        applicationName?: string | undefined;
    }) => {
        params: {};
        body: {};
        query: {
            applicationName: string | undefined;
        };
    };
};
export declare type ListDeployments = ExtractSchemaTypes<typeof ListDeploymentsSchema>;
export declare const DescribeDeploymentSchema: {
    Namespace: string;
    Description: string;
    Path: string;
    Method: "GET";
    Mode: "SYNC";
    Params: t.TypeC<{
        deploymentId: t.StringC;
    }>;
    Body: t.TypeC<{}>;
    Query: t.TypeC<{}>;
    Event: t.TypeC<{
        name: t.LiteralC<InstallerEventNames.describeDeployment>;
        payload: t.TypeC<{
            userId: t.StringC;
            deploymentId: t.StringC;
        }>;
    }>;
    Result: t.IntersectionC<[t.TypeC<{
        deploymentId: t.StringC;
        applicationName: t.StringC;
        version: t.StringC;
        domains: t.ArrayC<t.StringC>;
    }>, t.PartialC<{
        eventStoreId: t.StringC;
    }>]>;
    ArgumentsTransformer: ({ deploymentId }: {
        deploymentId: string;
    } & {} & {}) => {
        params: {
            deploymentId: string;
        };
        body: {};
        query: {};
    };
};
export declare type DescribeDeployment = ExtractSchemaTypes<typeof DescribeDeploymentSchema>;
export declare const BootstrapDeploymentSchema: {
    Namespace: string;
    Description: string;
    Path: string;
    Method: "PATCH";
    Mode: "ASYNC";
    Params: t.TypeC<{
        deploymentId: t.StringC;
    }>;
    Body: t.TypeC<{}>;
    Query: t.TypeC<{}>;
    Event: t.TypeC<{
        name: t.LiteralC<FactoryEventNames.bootstrapDeployment>;
        payload: t.TypeC<{
            version: t.StringC;
            userId: t.StringC;
            deploymentId: t.StringC;
        }>;
    }>;
    Result: t.VoidC;
    ArgumentsTransformer: ({ deploymentId }: {
        deploymentId: string;
    } & {} & {}) => {
        params: {
            deploymentId: string;
        };
        body: {};
        query: {};
    };
};
export declare type BootstrapDeployment = ExtractSchemaTypes<typeof BootstrapDeploymentSchema>;
export declare const ShutdownDeploymentSchema: {
    Namespace: string;
    Description: string;
    Path: string;
    Method: "PATCH";
    Mode: "ASYNC";
    Params: t.TypeC<{
        deploymentId: t.StringC;
    }>;
    Body: t.TypeC<{}>;
    Query: t.TypeC<{}>;
    Event: t.TypeC<{
        name: t.LiteralC<FactoryEventNames.shutdownDeployment>;
        payload: t.TypeC<{
            version: t.StringC;
            userId: t.StringC;
            deploymentId: t.StringC;
        }>;
    }>;
    Result: t.VoidC;
    ArgumentsTransformer: ({ deploymentId }: {
        deploymentId: string;
    } & {} & {}) => {
        params: {
            deploymentId: string;
        };
        body: {};
        query: {};
    };
};
export declare type ShutdownDeployment = ExtractSchemaTypes<typeof ShutdownDeploymentSchema>;
export declare const BuildDeploymentSchema: {
    Namespace: string;
    Description: string;
    Path: string;
    Method: "PATCH";
    Mode: "ASYNC";
    Params: t.TypeC<{
        deploymentId: t.StringC;
    }>;
    Body: t.PartialC<{
        npmRegistry: t.StringC;
    }>;
    Query: t.TypeC<{}>;
    Event: t.TypeC<{
        name: t.LiteralC<InstallerEventNames.buildDeployment>;
        payload: t.IntersectionC<[t.TypeC<{
            userId: t.StringC;
            deploymentId: t.StringC;
        }>, t.PartialC<{
            npmRegistry: t.StringC;
        }>]>;
    }>;
    Result: t.TypeC<{
        installLog: t.StringC;
        files: t.ArrayC<t.StringC>;
    }>;
    ArgumentsTransformer: ({ deploymentId, npmRegistry }: {
        deploymentId: string;
    } & {
        npmRegistry?: string | undefined;
    } & {}) => {
        params: {
            deploymentId: string;
        };
        body: {
            npmRegistry: string | undefined;
        };
        query: {};
    };
};
export declare type BuildDeployment = ExtractSchemaTypes<typeof BuildDeploymentSchema>;
export declare const GetDeploymentUploadSignedUrlSchema: {
    Namespace: string;
    Description: string;
    Path: string;
    Method: "GET";
    Mode: "SYNC";
    Params: t.TypeC<{
        deploymentId: t.StringC;
    }>;
    Body: t.TypeC<{}>;
    Query: t.TypeC<{}>;
    Event: t.TypeC<{
        name: t.LiteralC<InstallerEventNames.getDeploymentUploadSignedUrl>;
        payload: t.TypeC<{
            userId: t.StringC;
            deploymentId: t.StringC;
        }>;
    }>;
    Result: t.TypeC<{
        codeUploadUrl: t.StringC;
        staticUploadUrl: t.StringC;
    }>;
    ArgumentsTransformer: ({ deploymentId }: {
        deploymentId: string;
    } & {} & {}) => {
        params: {
            deploymentId: string;
        };
        body: {};
        query: {};
    };
};
export declare type GetDeploymentUploadSignedUrl = ExtractSchemaTypes<typeof GetDeploymentUploadSignedUrlSchema>;
