import * as t from 'io-ts';
import { InstallerEventNames } from '../../../constants';
import { ExtractSchemaTypes } from '../../../schemas';
export declare const EnableLogsSchema: {
    Namespace: string;
    Description: string;
    Path: string;
    Method: "PATCH";
    Mode: "SYNC";
    Params: t.TypeC<{
        deploymentId: t.StringC;
    }>;
    Body: t.PartialC<{
        logLevel: t.UnionC<[t.LiteralC<"log">, t.LiteralC<"error">, t.LiteralC<"warn">, t.LiteralC<"debug">, t.LiteralC<"info">, t.LiteralC<"verbose">]>;
        scope: t.StringC;
    }>;
    Query: t.TypeC<{}>;
    Event: t.TypeC<{
        name: t.LiteralC<InstallerEventNames.enableLogs>;
        payload: t.IntersectionC<[t.TypeC<{
            deploymentId: t.StringC;
            userId: t.StringC;
        }>, t.PartialC<{
            logLevel: t.UnionC<[t.LiteralC<"log">, t.LiteralC<"error">, t.LiteralC<"warn">, t.LiteralC<"debug">, t.LiteralC<"info">, t.LiteralC<"verbose">]>;
            scope: t.StringC;
        }>]>;
    }>;
    Result: t.VoidC;
    ArgumentsTransformer: ({ deploymentId, scope, logLevel }: {
        deploymentId: string;
    } & {
        logLevel?: "log" | "error" | "warn" | "debug" | "info" | "verbose" | undefined;
        scope?: string | undefined;
    } & {}) => {
        params: {
            deploymentId: string;
        };
        body: {
            scope: string | undefined;
            logLevel: "log" | "error" | "warn" | "debug" | "info" | "verbose" | undefined;
        };
        query: {};
    };
};
export declare type EnableLogs = ExtractSchemaTypes<typeof EnableLogsSchema>;
export declare const DisableLogsSchema: {
    Namespace: string;
    Description: string;
    Path: string;
    Method: "PATCH";
    Mode: "SYNC";
    Params: t.TypeC<{
        deploymentId: t.StringC;
    }>;
    Body: t.TypeC<{}>;
    Query: t.TypeC<{}>;
    Event: t.TypeC<{
        name: t.LiteralC<InstallerEventNames.disableLogs>;
        payload: t.TypeC<{
            deploymentId: t.StringC;
            userId: t.StringC;
        }>;
    }>;
    Result: t.VoidC;
    ArgumentsTransformer: ({ deploymentId }: {
        deploymentId: string;
    } & {} & {}) => {
        params: {
            deploymentId: string;
        };
        body: {};
        query: {};
    };
};
export declare type DisableLogs = ExtractSchemaTypes<typeof DisableLogsSchema>;
export declare const GetLogsSchema: {
    Namespace: string;
    Description: string;
    Path: string;
    Method: "GET";
    Mode: "SYNC";
    Params: t.TypeC<{
        deploymentId: t.StringC;
    }>;
    Body: t.TypeC<{}>;
    Query: t.PartialC<{
        startTime: t.StringC;
        endTime: t.StringC;
        filterPattern: t.StringC;
        streamLimit: t.StringC;
    }>;
    Event: t.TypeC<{
        name: t.LiteralC<InstallerEventNames.getLogs>;
        payload: t.IntersectionC<[t.TypeC<{
            deploymentId: t.StringC;
            userId: t.StringC;
        }>, t.PartialC<{
            streamLimit: t.NumberC;
            startTime: t.NumberC;
            endTime: t.NumberC;
            filterPattern: t.StringC;
        }>]>;
    }>;
    Result: t.StringC;
    ArgumentsTransformer: ({ deploymentId, streamLimit, startTime, endTime, filterPattern }: {
        deploymentId: string;
    } & {} & {
        startTime?: string | undefined;
        endTime?: string | undefined;
        filterPattern?: string | undefined;
        streamLimit?: string | undefined;
    }) => {
        params: {
            deploymentId: string;
        };
        body: {};
        query: {
            streamLimit: string | undefined;
            startTime: string | undefined;
            endTime: string | undefined;
            filterPattern: string | undefined;
        };
    };
};
export declare type GetLogs = ExtractSchemaTypes<typeof GetLogsSchema>;
export declare const RemoveLogsSchema: {
    Namespace: string;
    Description: string;
    Path: string;
    Method: "DELETE";
    Mode: "SYNC";
    Params: t.TypeC<{
        deploymentId: t.StringC;
    }>;
    Body: t.TypeC<{}>;
    Query: t.TypeC<{}>;
    Event: t.TypeC<{
        name: t.LiteralC<InstallerEventNames.removeLogs>;
        payload: t.TypeC<{
            deploymentId: t.StringC;
            userId: t.StringC;
        }>;
    }>;
    Result: t.VoidC;
    ArgumentsTransformer: ({ deploymentId }: {
        deploymentId: string;
    } & {} & {}) => {
        params: {
            deploymentId: string;
        };
        body: {};
        query: {};
    };
};
export declare type RemoveLogs = ExtractSchemaTypes<typeof RemoveLogsSchema>;
