import * as t from 'io-ts';
import { ExtractSchemaTypes } from '../../../schemas';
import { FactoryEventNames } from '../../../constants';
export declare const SetSagaPropertySchema: {
    Namespace: string;
    Description: string;
    Path: string;
    Method: "PUT";
    Mode: "SYNC";
    Params: t.TypeC<{
        deploymentId: t.StringC;
        sagaName: t.StringC;
    }>;
    Body: t.TypeC<{
        key: t.StringC;
        value: t.StringC;
    }>;
    Query: t.TypeC<{}>;
    Event: t.TypeC<{
        name: t.LiteralC<FactoryEventNames.setSagaProperty>;
        payload: t.TypeC<{
            version: t.StringC;
            deploymentId: t.StringC;
            userId: t.StringC;
            eventListener: t.StringC;
            key: t.StringC;
            value: t.StringC;
        }>;
    }>;
    Result: t.VoidC;
    ArgumentsTransformer: ({ deploymentId, sagaName, key, value }: {
        deploymentId: string;
        sagaName: string;
    } & {
        key: string;
        value: string;
    } & {}) => {
        params: {
            deploymentId: string;
            sagaName: string;
        };
        body: {
            key: string;
            value: string;
        };
        query: {};
    };
};
export declare type SetSagaProperty = ExtractSchemaTypes<typeof SetSagaPropertySchema>;
export declare const DeleteSagaPropertySchema: {
    Namespace: string;
    Description: string;
    Path: string;
    Method: "DELETE";
    Mode: "SYNC";
    Params: t.TypeC<{
        deploymentId: t.StringC;
        sagaName: t.StringC;
        key: t.StringC;
    }>;
    Body: t.TypeC<{}>;
    Query: t.TypeC<{}>;
    Event: t.TypeC<{
        name: t.LiteralC<FactoryEventNames.deleteSagaProperty>;
        payload: t.TypeC<{
            version: t.StringC;
            deploymentId: t.StringC;
            userId: t.StringC;
            eventListener: t.StringC;
            key: t.StringC;
        }>;
    }>;
    Result: t.VoidC;
    ArgumentsTransformer: ({ deploymentId, sagaName, key }: {
        deploymentId: string;
        sagaName: string;
        key: string;
    } & {} & {}) => {
        params: {
            deploymentId: string;
            sagaName: string;
            key: string;
        };
        body: {};
        query: {};
    };
};
export declare type DeleteSagaProperty = ExtractSchemaTypes<typeof DeleteSagaPropertySchema>;
export declare const GetSagaPropertySchema: {
    Namespace: string;
    Description: string;
    Path: string;
    Method: "GET";
    Mode: "SYNC";
    Params: t.TypeC<{
        deploymentId: t.StringC;
        sagaName: t.StringC;
        key: t.StringC;
    }>;
    Body: t.TypeC<{}>;
    Query: t.TypeC<{}>;
    Event: t.TypeC<{
        name: t.LiteralC<FactoryEventNames.getSagaProperty>;
        payload: t.TypeC<{
            version: t.StringC;
            deploymentId: t.StringC;
            userId: t.StringC;
            eventListener: t.StringC;
            key: t.StringC;
        }>;
    }>;
    Result: t.RecordC<t.StringC, t.AnyC>;
    ArgumentsTransformer: ({ deploymentId, sagaName, key }: {
        deploymentId: string;
        sagaName: string;
        key: string;
    } & {} & {}) => {
        params: {
            deploymentId: string;
            sagaName: string;
            key: string;
        };
        body: {};
        query: {};
    };
};
export declare type GetSagaProperty = ExtractSchemaTypes<typeof GetSagaPropertySchema>;
export declare const ListSagaPropertiesSchema: {
    Namespace: string;
    Description: string;
    Path: string;
    Method: "GET";
    Mode: "SYNC";
    Params: t.TypeC<{
        deploymentId: t.StringC;
        sagaName: t.StringC;
    }>;
    Body: t.TypeC<{}>;
    Query: t.TypeC<{}>;
    Event: t.TypeC<{
        name: t.LiteralC<FactoryEventNames.listSagaProperties>;
        payload: t.TypeC<{
            version: t.StringC;
            deploymentId: t.StringC;
            userId: t.StringC;
            eventListener: t.StringC;
        }>;
    }>;
    Result: t.AnyC;
    ArgumentsTransformer: ({ deploymentId, sagaName }: {
        deploymentId: string;
        sagaName: string;
    } & {} & {}) => {
        params: {
            deploymentId: string;
            sagaName: string;
        };
        body: {};
        query: {};
    };
};
export declare type ListSagaProperties = ExtractSchemaTypes<typeof ListSagaPropertiesSchema>;
