import * as t from 'io-ts';
import { InstallerEventNames } from '../../constants';
import { ExtractSchemaTypes } from '../../schemas';
export declare const CreateDomainSchema: {
    Namespace: string;
    Description: string;
    Path: string;
    Method: "POST";
    Mode: "ASYNC";
    Params: t.TypeC<{}>;
    Body: t.IntersectionC<[t.TypeC<{
        certificateId: t.StringC;
        aliases: t.ArrayC<t.StringC>;
    }>, t.PartialC<{
        domainId: t.StringC;
    }>]>;
    Query: t.TypeC<{}>;
    Event: t.TypeC<{
        name: t.UnionC<[t.LiteralC<InstallerEventNames.createStaticDomain>, t.LiteralC<InstallerEventNames.createProxyDomain>, t.LiteralC<InstallerEventNames.createUploaderDomain>]>;
        payload: t.IntersectionC<[t.TypeC<{
            userId: t.StringC;
            certificateId: t.StringC;
        }>, t.PartialC<{
            aliases: t.ArrayC<t.StringC>;
            domainId: t.StringC;
            customName: t.StringC;
            users: t.UnionC<[t.LiteralC<"*">, t.ArrayC<t.StringC>]>;
            verification: t.BooleanC;
        }>]>;
    }>;
    Result: t.TypeC<{
        domainId: t.StringC;
        domainType: t.UnionC<[t.LiteralC<"proxy">, t.LiteralC<"static">, t.LiteralC<"uploader">]>;
        domainName: t.StringC;
        resourceARN: t.StringC;
        aliases: t.ArrayC<t.StringC>;
        verified: t.BooleanC;
        owner: t.StringC;
        users: t.UnionC<[t.LiteralC<"*">, t.ArrayC<t.StringC>]>;
        verificationCode: t.StringC;
        certificateId: t.StringC;
    }>;
    ArgumentsTransformer: ({ certificateId, aliases, domainId }: {} & {
        certificateId: string;
        aliases: string[];
    } & {
        domainId?: string | undefined;
    } & {}) => {
        params: {};
        body: {
            certificateId: string;
            aliases: string[];
            domainId: string | undefined;
        };
        query: {};
    };
};
export declare type CreateDomain = ExtractSchemaTypes<typeof CreateDomainSchema>;
export declare const DropDomainSchema: {
    Namespace: string;
    Description: string;
    Path: string;
    Method: "DELETE";
    Mode: "ASYNC";
    Params: t.TypeC<{
        domainId: t.StringC;
    }>;
    Body: t.TypeC<{}>;
    Query: t.TypeC<{}>;
    Event: t.TypeC<{
        name: t.LiteralC<InstallerEventNames.dropDomain>;
        payload: t.TypeC<{
            userId: t.StringC;
            domainId: t.StringC;
        }>;
    }>;
    Result: t.VoidC;
    ArgumentsTransformer: ({ domainId }: {
        domainId: string;
    } & {} & {}) => {
        params: {
            domainId: string;
        };
        body: {};
        query: {};
    };
};
export declare type DropDomain = ExtractSchemaTypes<typeof DropDomainSchema>;
export declare const ReleaseDomainSchema: {
    Namespace: string;
    Description: string;
    Path: string;
    Method: "DELETE";
    Mode: "ASYNC";
    Params: t.TypeC<{}>;
    Body: t.TypeC<{
        domain: t.StringC;
    }>;
    Query: t.TypeC<{}>;
    Event: t.TypeC<{
        name: t.LiteralC<InstallerEventNames.releaseDomain>;
        payload: t.TypeC<{
            userId: t.StringC;
            domain: t.StringC;
        }>;
    }>;
    Result: t.VoidC;
    ArgumentsTransformer: ({ domain }: {} & {
        domain: string;
    } & {}) => {
        params: {};
        body: {
            domain: string;
        };
        query: {};
    };
};
export declare type ReleaseDomain = ExtractSchemaTypes<typeof ReleaseDomainSchema>;
export declare const ListDomainsSchema: {
    Namespace: string;
    Description: string;
    Path: string;
    Method: "GET";
    Mode: "SYNC";
    Params: t.TypeC<{}>;
    Body: t.TypeC<{}>;
    Query: t.TypeC<{}>;
    Event: t.TypeC<{
        name: t.LiteralC<InstallerEventNames.listDomains>;
        payload: t.IntersectionC<[t.TypeC<{
            userId: t.StringC;
        }>, t.PartialC<{
            domain: t.StringC;
        }>]>;
    }>;
    Result: t.ArrayC<t.TypeC<{
        domainId: t.StringC;
        domainType: t.UnionC<[t.LiteralC<"proxy">, t.LiteralC<"static">, t.LiteralC<"uploader">]>;
        domainName: t.StringC;
        resourceARN: t.StringC;
        aliases: t.ArrayC<t.StringC>;
        verified: t.BooleanC;
        owner: t.StringC;
        users: t.UnionC<[t.LiteralC<"*">, t.ArrayC<t.StringC>]>;
        verificationCode: t.StringC;
        certificateId: t.StringC;
    }>>;
    ArgumentsTransformer: (args?: {} & {} & {}) => {
        params: {};
        body: {};
        query: {};
    };
};
export declare type ListDomains = ExtractSchemaTypes<typeof ListDomainsSchema>;
export declare const VerifyDomainSchema: {
    Namespace: string;
    Description: string;
    Path: string;
    Method: "PATCH";
    Mode: "ASYNC";
    Params: t.TypeC<{
        domainId: t.StringC;
    }>;
    Body: t.TypeC<{}>;
    Query: t.TypeC<{}>;
    Event: t.TypeC<{
        name: t.LiteralC<InstallerEventNames.verifyDomain>;
        payload: t.TypeC<{
            userId: t.StringC;
            domainId: t.StringC;
        }>;
    }>;
    Result: t.VoidC;
    ArgumentsTransformer: ({ domainId }: {
        domainId: string;
    } & {} & {}) => {
        params: {
            domainId: string;
        };
        body: {};
        query: {};
    };
};
export declare type VerifyDomain = ExtractSchemaTypes<typeof VerifyDomainSchema>;
export declare const GetVerificationCodeSchema: {
    Namespace: string;
    Description: string;
    Path: string;
    Method: "GET";
    Mode: "SYNC";
    Params: t.TypeC<{
        domainId: t.StringC;
    }>;
    Body: t.TypeC<{}>;
    Query: t.TypeC<{}>;
    Event: t.TypeC<{
        name: t.LiteralC<InstallerEventNames.getVerificationCode>;
        payload: t.TypeC<{
            userId: t.StringC;
            domainId: t.StringC;
        }>;
    }>;
    Result: t.TypeC<{
        verificationCode: t.StringC;
    }>;
    ArgumentsTransformer: ({ domainId }: {
        domainId: string;
    } & {} & {}) => {
        params: {
            domainId: string;
        };
        body: {};
        query: {};
    };
};
export declare type GetVerificationCode = ExtractSchemaTypes<typeof GetVerificationCodeSchema>;
