import { Heartbeat } from './api/v0/cloud';
import { ListDeployments } from './api/v0/deployments/lifecycle';
import { GetLogs } from './api/v0/deployments/logs';
import { GetImportUrls } from './api/v0/event-stores';
import { SetupOptions } from './cloud-sdk-setup-options';
import { Deployment } from './schemas';
export declare const createCloudSdk: () => {
    setup(params: SetupOptions): void;
    heartbeat(args?: Heartbeat['Params'] & Heartbeat['Query'] & Heartbeat['Body']): Promise<Heartbeat['Result']>;
    getDeploymentByApplicationName(args: {
        applicationName: string;
    }): Promise<Deployment | null>;
    getClientAppConfig: (args?: ({} & {} & {}) | undefined) => Promise<{
        clientId: string;
        userPoolId: string;
    }>;
    listVersions: (args?: ({} & {} & {}) | undefined) => Promise<string[]>;
    createDeployment: (args?: ({} & {
        applicationName: string;
        version: string;
        eventStoreId: string;
    } & {
        domain?: string | undefined;
    } & {}) | undefined) => Promise<{
        deploymentId: string;
        applicationName: string;
        version: string;
        domains: string[];
    } & {
        eventStoreId?: string | undefined;
    }>;
    dropDeployment: (args?: ({
        deploymentId: string;
    } & {
        withEventStore?: boolean | undefined;
    } & {}) | undefined) => Promise<void>;
    describeDeployment: (args?: ({
        deploymentId: string;
    } & {} & {}) | undefined) => Promise<{
        deploymentId: string;
        applicationName: string;
        version: string;
        domains: string[];
    } & {
        eventStoreId?: string | undefined;
    }>;
    listDeployments(args?: {}): Promise<ListDeployments['Result']>;
    bootstrapDeployment: (args?: ({
        deploymentId: string;
    } & {} & {}) | undefined) => Promise<void>;
    shutdownDeployment: (args?: ({
        deploymentId: string;
    } & {} & {}) | undefined) => Promise<void>;
    buildDeployment: (args?: ({
        deploymentId: string;
    } & {
        npmRegistry?: string | undefined;
    } & {}) | undefined) => Promise<{
        installLog: string;
        files: string[];
    }>;
    getDeploymentUploadSignedUrl: (args?: ({
        deploymentId: string;
    } & {} & {}) | undefined) => Promise<{
        codeUploadUrl: string;
        staticUploadUrl: string;
    }>;
    setDeploymentDomain: (args?: ({
        deploymentId: string;
    } & {
        domain: string;
    } & {}) | undefined) => Promise<void>;
    unsetDeploymentDomain: (args?: ({
        deploymentId: string;
    } & {
        domain: string;
    } & {}) | undefined) => Promise<void>;
    linkDeployment: (args?: ({
        eventStoreId: string;
    } & {
        deploymentId: string;
    } & {}) | undefined) => Promise<void>;
    unlinkDeployment: (args?: ({
        eventStoreId: string;
    } & {
        deploymentId: string;
    } & {}) | undefined) => Promise<void>;
    listEnvironmentVariables: (args?: ({
        deploymentId: string;
    } & {} & {}) | undefined) => Promise<{
        [x: string]: string;
    }>;
    removeEnvironmentVariables: (args?: ({
        deploymentId: string;
    } & {
        variables: string[];
    } & {}) | undefined) => Promise<void>;
    setEnvironmentVariables: (args?: ({
        deploymentId: string;
    } & {
        variables: {
            [x: string]: string;
        };
    } & {}) | undefined) => Promise<void>;
    disableLogs: (args?: ({
        deploymentId: string;
    } & {} & {}) | undefined) => Promise<void>;
    enableLogs: (args?: ({
        deploymentId: string;
    } & {
        logLevel?: "log" | "error" | "warn" | "debug" | "info" | "verbose" | undefined;
        scope?: string | undefined;
    } & {}) | undefined) => Promise<void>;
    getLogs(args: {
        deploymentId: string;
        streamLimit?: number;
        startTime?: number;
        endTime?: number;
        filterPattern?: string;
    }): Promise<GetLogs['Result']>;
    removeLogs: (args?: ({
        deploymentId: string;
    } & {} & {}) | undefined) => Promise<void>;
    listSagas: (args?: ({
        deploymentId: string;
    } & {} & {}) | undefined) => Promise<{
        name: string;
        status: string | null;
        successEvent: {
            [x: string]: any;
        } | null;
        failedEvent: {
            [x: string]: any;
        } | null;
        errors: {
            name: string;
            message: string;
            stack: string;
        }[];
    }[]>;
    pauseSaga: (args?: ({
        deploymentId: string;
        sagaName: string;
    } & {} & {}) | undefined) => Promise<any>;
    resetSaga: (args?: ({
        deploymentId: string;
        sagaName: string;
    } & {} & {}) | undefined) => Promise<void>;
    resumeSaga: (args?: ({
        deploymentId: string;
        sagaName: string;
    } & {} & {}) | undefined) => Promise<void>;
    listSagaProperties: (args?: ({
        deploymentId: string;
        sagaName: string;
    } & {} & {}) | undefined) => Promise<any>;
    setSagaProperty: (args?: ({
        deploymentId: string;
        sagaName: string;
    } & {
        key: string;
        value: string;
    } & {}) | undefined) => Promise<void>;
    getSagaProperty: (args?: ({
        deploymentId: string;
        sagaName: string;
        key: string;
    } & {} & {}) | undefined) => Promise<{
        [x: string]: any;
    }>;
    deleteSagaProperty: (args?: ({
        deploymentId: string;
        sagaName: string;
        key: string;
    } & {} & {}) | undefined) => Promise<void>;
    listReadModels: (args?: ({
        deploymentId: string;
    } & {} & {}) | undefined) => Promise<{
        name: string;
        status: string | null;
        successEvent: {
            [x: string]: any;
        } | null;
        failedEvent: {
            [x: string]: any;
        } | null;
        errors: {
            name: string;
            message: string;
            stack: string;
        }[];
    }[]>;
    pauseReadModel: (args?: ({
        deploymentId: string;
        readModelName: string;
    } & {} & {}) | undefined) => Promise<void>;
    resetReadModel: (args?: ({
        deploymentId: string;
        readModelName: string;
    } & {} & {}) | undefined) => Promise<void>;
    resumeReadModel: (args?: ({
        deploymentId: string;
        readModelName: string;
    } & {} & {}) | undefined) => Promise<void>;
    getTracingDetails: (args?: ({
        deploymentId: string;
    } & {} & {
        traceIds: string[];
    }) | undefined) => Promise<{
        [x: string]: any;
    }[]>;
    getTracingStatus: (args?: ({
        deploymentId: string;
    } & {} & {}) | undefined) => Promise<"enabled" | "disabled">;
    getSummaries: (args?: ({
        deploymentId: string;
    } & {} & {
        startTime: string;
        endTime: string;
    } & {
        filterExpression?: string | undefined;
    }) | undefined) => Promise<({
        id?: string | undefined;
        responseTime?: number | undefined;
        http?: {
            httpURL?: string | undefined;
            httpStatus?: number | undefined;
            httpMethod?: string | undefined;
            userAgent?: string | undefined;
            clientIp?: string | undefined;
        } | undefined;
    } & {
        [x: string]: any;
    })[]>;
    enableTracing: (args?: ({
        deploymentId: string;
    } & {} & {}) | undefined) => Promise<void>;
    disableTracing: (args?: ({
        deploymentId: string;
    } & {} & {}) | undefined) => Promise<void>;
    listEventStores: (args?: ({} & {} & {}) | undefined) => Promise<{
        version: string;
        eventStoreId: string;
        linkedDeployments: string[];
        eventStoreDatabaseName: string;
        events: number | null;
        secrets: number | null;
        modifiedAt: number | null;
        createdAt: number | null;
        isFrozen: boolean | null;
    }[]>;
    cloneEventStore: (args?: ({
        eventStoreId: string;
    } & {} & {}) | undefined) => Promise<{
        eventStoreId: string;
        eventStoreDatabaseName: string;
    }>;
    createEventStore: (args?: ({} & {
        version: string;
    } & {}) | undefined) => Promise<{
        eventStoreId: string;
    }>;
    dropEventStore: (args?: ({
        eventStoreId: string;
    } & {} & {}) | undefined) => Promise<void>;
    getEventStore: (args?: ({
        eventStoreId: string;
    } & {} & {}) | undefined) => Promise<{
        eventStoreClusterArn: string;
        eventStoreSecretArn: string;
        eventStoreDatabaseName: string;
        version: string;
        eventStoreId: string;
        linkedDeployments: string[];
        region: string;
        accessKeyId: string;
        secretAccessKey: string;
        sessionToken: string;
    }>;
    clearEventStore: (args?: ({
        eventStoreId: string;
    } & {} & {}) | undefined) => Promise<void>;
    freezeEventStore: (args?: ({
        eventStoreId: string;
    } & {} & {}) | undefined) => Promise<void>;
    unfreezeEventStore: (args?: ({
        eventStoreId: string;
    } & {} & {}) | undefined) => Promise<void>;
    exportEvents: (args?: ({
        eventStoreId: string;
    } & {} & {
        cursor?: string | undefined;
    }) | undefined) => Promise<void>;
    importEvents: (args?: ({
        eventStoreId: string;
    } & {
        partIndex: number;
    } & {}) | undefined) => Promise<void>;
    getExportUrls: (args?: ({
        eventStoreId: string;
    } & {} & {}) | undefined) => Promise<{
        eventsExportUrl: string;
        secretsExportUrl: string;
        statusFileUrl: string;
    }>;
    getImportUrls(args: {
        eventStoreId: string;
        eventsPartCount: number;
        secretsPartCount: number;
    }): Promise<GetImportUrls['Result']>;
    listCertificates: (args?: ({} & {} & {}) | undefined) => Promise<({
        certificateId: string;
        additionalNames: string[];
        resourceARN: string;
    } & {
        domainName?: string | undefined;
        importedAt?: string | undefined;
        issuer?: string | undefined;
        notBefore?: string | undefined;
        notAfter?: string | undefined;
    })[]>;
    dropCertificate: (args?: ({
        certificateId: string;
    } & {} & {}) | undefined) => Promise<void>;
    ensureCertificate: (args?: ({} & {
        certificate: string;
        key: string;
    } & {
        certificateId?: string | undefined;
        chain?: string | undefined;
    } & {}) | undefined) => Promise<string>;
    createDomain: (args?: ({} & {
        certificateId: string;
        aliases: string[];
    } & {
        domainId?: string | undefined;
    } & {}) | undefined) => Promise<{
        domainId: string;
        domainType: "proxy" | "static" | "uploader";
        domainName: string;
        resourceARN: string;
        aliases: string[];
        verified: boolean;
        owner: string;
        users: string[] | "*";
        verificationCode: string;
        certificateId: string;
    }>;
    dropDomain: (args?: ({
        domainId: string;
    } & {} & {}) | undefined) => Promise<void>;
    getVerificationCode: (args?: ({
        domainId: string;
    } & {} & {}) | undefined) => Promise<{
        verificationCode: string;
    }>;
    listDomains: (args?: ({} & {} & {}) | undefined) => Promise<{
        domainId: string;
        domainType: "proxy" | "static" | "uploader";
        domainName: string;
        resourceARN: string;
        aliases: string[];
        verified: boolean;
        owner: string;
        users: string[] | "*";
        verificationCode: string;
        certificateId: string;
    }[]>;
    verifyDomain: (args?: ({
        domainId: string;
    } & {} & {}) | undefined) => Promise<void>;
    releaseDomain: (args?: ({} & {
        domain: string;
    } & {}) | undefined) => Promise<void>;
};
export declare type CloudSdk = ReturnType<typeof createCloudSdk>;
